.. django Organice documentation master file, created by sphinx-quickstart on Thu Feb 20 23:16:50 2014.
   You can adapt this file completely to your liking, but it should at least contain the root `toctree` directive.

.. include:: ../README.rst
    :end-before: Fundamental Features

Also available in the cloud.  Nice, very nice, http://organice.io


Contents
========

.. toctree::
   :maxdepth: 2

   overview
   installation
   configuration
   themes
   components
   contributing
   alternatives
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
